# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_tools_item_name_item import (
    TemplatesCreateAgentsResponseAgentsItemToolsItemNameItem,
)

TemplatesCreateAgentsResponseAgentsItemToolsItemName = typing.Union[
    str, typing.Optional[str], typing.List[typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolsItemNameItem]]
]
