# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .agents_search_response_agents_item_sources_item_id import AgentsSearchResponseAgentsItemSourcesItemId
from .agents_search_response_agents_item_sources_item_description import (
    AgentsSearchResponseAgentsItemSourcesItemDescription,
)
from .agents_search_response_agents_item_sources_item_embedding_config import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig,
)
from .agents_search_response_agents_item_sources_item_organization_id import (
    AgentsSearchResponseAgentsItemSourcesItemOrganizationId,
)
from .agents_search_response_agents_item_sources_item_metadata import AgentsSearchResponseAgentsItemSourcesItemMetadata
from .agents_search_response_agents_item_sources_item_created_by_id import (
    AgentsSearchResponseAgentsItemSourcesItemCreatedById,
)
from .agents_search_response_agents_item_sources_item_last_updated_by_id import (
    AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById,
)
from .agents_search_response_agents_item_sources_item_created_at import (
    AgentsSearchResponseAgentsItemSourcesItemCreatedAt,
)
from .agents_search_response_agents_item_sources_item_updated_at import (
    AgentsSearchResponseAgentsItemSourcesItemUpdatedAt,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AgentsSearchResponseAgentsItemSourcesItem(UncheckedBaseModel):
    id: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemId] = None
    name: str
    description: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemDescription] = None
    embedding_config: AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig
    organization_id: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemOrganizationId] = None
    metadata: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemMetadata] = None
    created_by_id: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemCreatedById] = None
    last_updated_by_id: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById] = None
    created_at: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemCreatedAt] = None
    updated_at: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemUpdatedAt] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
