# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_created_by_id import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_created_at import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_updated_at import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_id import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemId,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_description import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
)
from .templates_create_agents_response_agents_item_tool_exec_environment_variables_item_organization_id import (
    TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItem(UncheckedBaseModel):
    created_by_id: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById
    ] = None
    last_updated_by_id: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById
    ] = None
    created_at: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt] = None
    updated_at: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt] = None
    id: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemId] = None
    key: str
    value: str
    description: typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemDescription] = (
        None
    )
    organization_id: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId
    ] = None
    agent_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
