# This file was auto-generated by Fern from our API Definition.

import typing

TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIdsManagerType = typing.Union[
    typing.Literal["round_robin", "supervisor", "dynamic", "swarm"], typing.Any
]
