# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_multi_agent_group_agent_ids import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIds,
)
from .templates_create_agents_response_agents_item_multi_agent_group_item import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItem,
)

TemplatesCreateAgentsResponseAgentsItemMultiAgentGroup = typing.Union[
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupAgentIds,
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItem]],
    typing.Optional[typing.Any],
]
