# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_tool_rules_item_item_child_output_mapping_default_child_item import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem,
)

TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild = typing.Union[
    str,
    typing.Optional[str],
    typing.List[
        typing.Optional[TemplatesCreateAgentsResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem]
    ],
    typing.Optional[typing.Any],
]
