# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_tool_rules_item_item import (
    TemplatesCreateAgentsResponseAgentsItemToolRulesItemItem,
)

TemplatesCreateAgentsResponseAgentsItemToolRulesItem = typing.Union[
    typing.List[TemplatesCreateAgentsResponseAgentsItemToolRulesItemItem], typing.Optional[str]
]
