# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .agents_search_response_agents_item_memory_blocks_item_limit import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLimit,
)
from .agents_search_response_agents_item_memory_blocks_item_name import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemName,
)
from .agents_search_response_agents_item_memory_blocks_item_is_template import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate,
)
from .agents_search_response_agents_item_memory_blocks_item_label import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLabel,
)
from .agents_search_response_agents_item_memory_blocks_item_description import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemDescription,
)
from .agents_search_response_agents_item_memory_blocks_item_metadata import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata,
)
from .agents_search_response_agents_item_memory_blocks_item_id import AgentsSearchResponseAgentsItemMemoryBlocksItemId
from .agents_search_response_agents_item_memory_blocks_item_organization_id import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId,
)
from .agents_search_response_agents_item_memory_blocks_item_created_by_id import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById,
)
from .agents_search_response_agents_item_memory_blocks_item_last_updated_by_id import (
    AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AgentsSearchResponseAgentsItemMemoryBlocksItem(UncheckedBaseModel):
    value: str
    limit: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemLimit] = None
    name: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemName] = None
    is_template: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate] = None
    label: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemLabel] = None
    description: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemDescription] = None
    metadata: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata] = None
    id: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemId] = None
    organization_id: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId] = None
    created_by_id: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById] = None
    last_updated_by_id: typing.Optional[AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
