# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_manager_type import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerType,
)
import typing
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_manager_agent_id import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentId,
)
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_termination_token import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationToken,
)
from .templates_create_agents_response_agents_item_multi_agent_group_item_agent_ids_max_turns import (
    TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurns,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIds(UncheckedBaseModel):
    id: str
    manager_type: TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerType
    agent_ids: typing.List[str]
    description: str
    manager_agent_id: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsManagerAgentId
    ] = None
    termination_token: typing.Optional[
        TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationToken
    ] = None
    max_turns: typing.Optional[TemplatesCreateAgentsResponseAgentsItemMultiAgentGroupItemAgentIdsMaxTurns] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
