# This file was auto-generated by Fern from our API Definition.

import typing
from .components_schemas_text_content import ComponentsSchemasTextContent

UpdateAssistantMessageContent = typing.Union[typing.List[ComponentsSchemasTextContent], str]
