# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_multi_agent_group_item_agent_ids import (
    AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIds,
)

AgentsSearchResponseAgentsItemMultiAgentGroupItem = typing.Union[
    AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIds, typing.Optional[str]
]
