# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_response_agents_item_message_ids_item import (
    TemplatesCreateAgentsResponseAgentsItemMessageIdsItem,
)

TemplatesCreateAgentsResponseAgentsItemMessageIds = typing.Union[
    typing.List[str],
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsResponseAgentsItemMessageIdsItem]],
    typing.Optional[typing.Any],
]
