# This file was auto-generated by Fern from our API Definition.

import typing

ChatCompletionAudioParamVoice = typing.Union[
    typing.Literal["alloy", "ash", "ballad", "coral", "echo", "sage", "shimmer", "verse"], typing.Any
]
