# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_tool_rules_item import AgentsSearchResponseAgentsItemToolRulesItem

AgentsSearchResponseAgentsItemToolRules = typing.Union[
    typing.List[AgentsSearchResponseAgentsItemToolRulesItem],
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemToolRulesItem]],
    typing.Optional[typing.Any],
]
