# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_multi_agent_group_item_agent_ids_termination_token_item import (
    AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationTokenItem,
)

AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationToken = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemMultiAgentGroupItemAgentIdsTerminationTokenItem]],
    typing.Optional[typing.Any],
]
