# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_multi_agent_group_agent_ids import (
    AgentsSearchResponseAgentsItemMultiAgentGroupAgentIds,
)
from .agents_search_response_agents_item_multi_agent_group_item import AgentsSearchResponseAgentsItemMultiAgentGroupItem

AgentsSearchResponseAgentsItemMultiAgentGroup = typing.Union[
    AgentsSearchResponseAgentsItemMultiAgentGroupAgentIds,
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemMultiAgentGroupItem]],
    typing.Optional[typing.Any],
]
